@@ -280,7 +280,7 @@ class AppTool(object):
                     mailhost = (smtp['host'], smtp['port']),
                     fromaddr = from_addr,
                     toaddrs = to_addrs,
-                    subject = '[%(levelname)s] - %(name)s - %(message)s',
+                    subject = '%(name)s - %(levelname)s - %(message)s',
                     credentials = (smtp['user'], smtp['pwd']))
             mail_handler.setLevel(logging.ERROR)
             logger.addHandler(mail_handler)
@@ -324,6 +324,7 @@ class AppTool(object):
 
     def log(self, reRaise=False, message=''):
         """Decorator
+        !!! Should be decorated first to avoid being shielded by other decorators, such as @click.
         
         Keyword Arguments:
             reRaise {bool} -- Re-raise exception (default: {False})
